{% extends "!footer.html" %}

{% block extrafooter %}
<p>
  <a href="https://www.linuxfoundation.org/legal/privacy-policy">Privacy Policy</a>
  |
  <a href="https://www.linuxfoundation.org/legal/terms">Terms of Use</a>
</p>
{{ super() }}
{% endblock %}
