project = 'Korgalore'
copyright = '2025, The Linux Foundation and contributors'
author = 'Kernel.org'
templates_path = ['_templates']
html_theme = 'sphinx_rtd_theme'
html_logo = 'korgalore-logo.png'
highlight_language = 'none'
master_doc = 'index'